;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "stgit" "20251110.503"
  "Major mode for StGit interaction."
  ()
  :url "http://stacked-git.github.io"
  :commit "020140581698f62d846c995ee6e3bebe0c20ff14"
  :revdesc "020140581698"
  :authors '(("David Kågedal" . "davidk@lysator.liu.se"))
  :maintainers '(("David Kågedal" . "davidk@lysator.liu.se")))
